@@ -53,24 +53,20 @@ class EntryType(Enum):
     Security = 6
 
 
-def public_entry_text(text):
-    '''Strips any "[#NN]" part of the text'''
-    return re.sub(' *\[#[0-9]+\]', '', text)
+# A reference to a ticket (e.g. #123 or libats#12), usually at the end of each
+# entry
+TicketRef = namedtuple('TicketRef', [
+    'number', # type: int
+    'repo',   # type: Optional[str]
+])
 
-def entry_text(text, internal):
-    if internal:
-        return text
-    else:
-        return public_entry_text(text)
-
-
-# Represents an entry in a change log
-EntryLog = namedtuple('EntryLog', [ 
+# Represents an entry in a change log. The associated tickets may be an empty list
+EntryLog = namedtuple('EntryLog', [
     'internal',  # type: bool
     'text',      # type: str
+    'tickets',   # type: List[TicketRef]
     ])
 
-
 # A category of change logs for a given version
 CategoryLog = namedtuple('CategoryLog', [
     'entry_type',  # type: EntryType
@@ -128,13 +124,20 @@ class ChangeLogRuleVisitor(NodeVisitor):
         h3 = "### " word _
         word = ~"[\w]+"
         entries = entry+
-        entry = "- " maybe_internal textparagraph _
+        entry = "- " maybe_internal textparagraph maybe_ticketrefs _
         maybe_internal = (~"\[INTERNAL\]"i)?
 
+        maybe_ticketrefs = ticketrefs?
+        ticketrefs = "[" ticketref maybe_ticketref_list_end  "]"
+        maybe_ticketref_list_end = ticketref_list_element*
+        ticketref_list_element = _ "," _ ticketref
+        ticketref = ~"[A-Za-z]*#[0-9]+"
+
         maybe_textparagraph = textparagraph?
         # `textparagraph` matches any text, and stops at either a dash or a
-        # pound characters at the start of a line.
-        textparagraph = ~"[^-#].+?((?=^-)|(?=^#)|\Z)"ms
+        # pound characters at the start of a line, or at an opening square
+        # bracket
+        textparagraph = ~"[^-#].+?((?=^-)|(?=^#)|\Z|(?=\[))"ms
         _ = meaningless*
         meaningless = ~"[\s]+"
 
@@ -232,7 +235,7 @@ class ChangeLogRuleVisitor(NodeVisitor):
         return ""
 
     def visit_textparagraph(self, node, _):
-        return node.text.strip()
+        return re.sub(r'\s*\n\s*', ' ', node.text.strip())
 
     def visit_maybe_internal(self, node, _):
         if node.text:
@@ -240,7 +243,29 @@ class ChangeLogRuleVisitor(NodeVisitor):
         return False
 
     def visit_entry(self, _, childs):
-        return EntryLog(childs[1], childs[2])
+        return EntryLog(childs[1], childs[2], childs[3])
+
+    def visit_maybe_ticketrefs(self, node, childs):
+        if node.text:
+            return childs[0]
+        return []
+
+    def visit_ticketrefs(self, _, childs):
+        return [childs[1], *childs[2]]
+
+    def visit_maybe_ticketref_list_end(self, _, childs):
+        return childs
+
+    def visit_ticketref_list_element(self, _, childs):
+        return childs[3]
+
+    def visit_ticketref(self, node, _):
+        repo, sep, number = node.text.partition('#')
+        if not sep:
+            raise ValueError("Separator not found in {}".format(node.text))
+        if repo:
+            return TicketRef(int(number), repo)
+        return TicketRef(int(number), None)
 
     def visit_entries(self, _, childs):
         return childs
@@ -298,6 +323,18 @@ class ChangeLogRuleVisitor(NodeVisitor):
     def visit_changelog(self, _, childs):
         return ChangeLog(childs[0], childs[1], childs[2])
 
+def ticketref_text(ticketref: TicketRef):
+    if ticketref.repo is not None:
+        return "{}#{}".format(ticketref.repo, ticketref.number)
+    return "#{}".format(ticketref.number)
+
+def entry_text(entry: EntryLog, output_internal: bool):
+    text = entry.text
+    if output_internal and len(entry.tickets):
+        text += " ["
+        text += ", ".join([ticketref_text(t) for t in entry.tickets])
+        text += "]"
+    return text
 
 def version_log_empty(vlog, output_internal=False):
     '''A version log is considered empty if it would not output any entry'''
@@ -395,7 +432,7 @@ def changelog_to_html(changelog, output_internal=False):
             for entry in cat.logs:
                 if entry.internal and not output_internal:
                     continue
-                out = out + "    <li>{}</li>\n".format(entry_text(entry.text, output_internal))
+                out = out + "    <li>{}</li>\n".format(entry_text(entry, output_internal))
             out = out + "</ul>\n"
     return out
 
@@ -422,9 +459,9 @@ def changelog_to_md(changelog,
             for entry in cat.logs:
                 if entry.internal:
                     if output_internal:
-                        out = out + "\n- [Internal] {}".format(entry_text(entry.text, output_internal))
+                        out = out + "\n- [Internal] {}".format(entry_text(entry, output_internal))
                 else:
-                    out = out + "\n- {}".format(entry_text(entry.text, output_internal))
+                    out = out + "\n- {}".format(entry_text(entry, output_internal))
             out = out + "\n"
     return out
 
@@ -444,7 +481,7 @@ def changelog_to_deb(changelog, package_name,
                 for entry in cat.logs:
                     if entry.internal and not output_internal:
                         continue
-                    out = out + "  * {}: {}\n".format(cat.entry_type.name, entry_text(entry.text, output_internal))
+                    out = out + "  * {}: {}\n".format(cat.entry_type.name, entry_text(entry, output_internal))
 
         out = out + "\n -- AlazarTech <support@alazartech.com>  {} 12:12:00 -0400\n\n".format(dat.strftime('%a, %d %b %Y'))
     return out
@@ -468,7 +505,7 @@ def expand_spec(changelog, input_text,
             for entry in cat.logs:
                 if entry.internal and not output_internal:
                     continue
-                out = out + "- {}: {}\n".format(cat.entry_type.name, entry_text(entry.text, output_internal))
+                out = out + "- {}: {}\n".format(cat.entry_type.name, entry_text(entry, output_internal))
 
     return out
 
