@@ -193,10 +193,11 @@ def register(development, passfile, specsfile, baseurl, version, dry_run):
         with open(passfile, 'r') as passf:
             password = passf.readline().strip()
     payload = payload_from_packages(packages, baseurl, version, password)
+    print("The POST request parameters:")
+    print("- endpoint: {}".format(endpoint))
+    print("- data: {}".format(payload))
     if dry_run:
-        print("Dry run, stopping here. The POST request would have been run with:")
-        print("- endpoint: {}".format(endpoint))
-        print("- data: {}".format(payload))
+        print("Dry run, stopping here.")
         return
     res = requests.post(endpoint,
                         params={"key": getenv("WEBSITE_API_KEY")},
