@@ -16,6 +16,10 @@ This file contains all important changes to the AlazarTech deployment tools
 ## [0.0.1] - 2019-01-23
 ### Added
 - Initial version: deploy.py [#3]
+- Look at this other problem [libats#123]
+- This solves many things. Line
+  break. [libats#123, #34]
+
 """
 
 CHANGELOG = clp.ChangeLog(
@@ -23,28 +27,30 @@ CHANGELOG = clp.ChangeLog(
     "This file contains all important changes to the AlazarTech deployment tools",
     [
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(True, 0, 0, 0, "", ""), datetime.date.today(),
-                False), []),
+            clp.VersionInfo(clp.VersionNumber(True, 0, 0, 0, "", ""),
+                            datetime.date.today(), False), []),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 0, 0, 2, "", ""), datetime.date(2019, 1, 25),
-                False),
+            clp.VersionInfo(clp.VersionNumber(False, 0, 0, 2, "", ""),
+                            datetime.date(2019, 1, 25), False),
             [
                 clp.CategoryLog(clp.EntryType.Fixed, [
                     clp.EntryLog(
                         True,
-                        "Make directory copy work even if destination already exists"
+                        "Make directory copy work even if destination already exists",
+                        [],
                     ),
                 ])
             ]),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 0, 0, 1, "", ""), datetime.date(2019, 1, 23),
-                False), [
+            clp.VersionInfo(clp.VersionNumber(
+                False, 0, 0, 1, "", ""), datetime.date(2019, 1, 23), False), [
                     clp.CategoryLog(clp.EntryType.Added, [
-                        clp.EntryLog(False, "Initial version: deploy.py [#3]"),
-                    ])
+                        clp.EntryLog(False, "Initial version: deploy.py",
+                                     [clp.TicketRef(3, None)]),
+                        clp.EntryLog(False, "Look at this other problem",
+                                     [clp.TicketRef(123, "libats")]),
+                        clp.EntryLog(False, "This solves many things. Line break.", [clp.TicketRef(123, "libats"), clp.TicketRef(34, None)])
+                    ]),
                 ]),
     ],
 )
@@ -73,40 +79,38 @@ CHANGELOG2 = clp.ChangeLog(
     "",
     [
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 1, 3, 0, "", ""), datetime.date(2019, 3, 19),
-                False), [
+            clp.VersionInfo(clp.VersionNumber(False, 1, 3, 0, "", ""),
+                            datetime.date(2019, 3, 19), False),
+            [
+                clp.CategoryLog(clp.EntryType.Added, [
+                    clp.EntryLog(
+                        False, "Support for forward slashes \"/\" in net name",
+                        []),
+                ]),
+            ]),
+        clp.VersionLog(
+            clp.VersionInfo(clp.VersionNumber(False, 1, 2, 0, "", ""),
+                            datetime.date(2019, 3, 19), True),
+            [
+                clp.CategoryLog(clp.EntryType.Changed, [
+                    clp.EntryLog(False, "Use net name in exported file", []),
+                ]),
+            ]),
+        clp.VersionLog(
+            clp.VersionInfo(clp.VersionNumber(
+                False, 1, 1, 0, "", ""), datetime.date(2019, 3, 19), False), [
                     clp.CategoryLog(clp.EntryType.Added, [
                         clp.EntryLog(
-                            False,
-                            "Support for forward slashes \"/\" in net name"),
+                            False, "Error message window on failed parse", []),
                     ]),
                 ]),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 1, 2, 0, "", ""), datetime.date(2019, 3, 19),
-                True), [
-                    clp.CategoryLog(clp.EntryType.Changed, [
-                        clp.EntryLog(False, "Use net name in exported file"),
-                    ]),
-                ]),
-        clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 1, 1, 0, "", ""), datetime.date(
-                    2019, 3, 19), False), [
-                        clp.CategoryLog(clp.EntryType.Added, [
-                            clp.EntryLog(
-                                False, "Error message window on failed parse"),
-                        ]),
-                    ]),
-        clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 1, 0, 0, "", ""), datetime.date(2019, 3, 18),
-                False), [
-                    clp.CategoryLog(clp.EntryType.Added, [
-                        clp.EntryLog(False, "Initial version"),
-                    ]),
-                ]),
+            clp.VersionInfo(clp.VersionNumber(False, 1, 0, 0, "", ""),
+                            datetime.date(2019, 3, 18), False), [
+                                clp.CategoryLog(clp.EntryType.Added, [
+                                    clp.EntryLog(False, "Initial version", []),
+                                ]),
+                            ]),
     ],
 )
 
@@ -130,62 +134,57 @@ CHANGELOG3 = clp.ChangeLog(
     "",
     [
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 1, 2, 0, "rc2", "12"), datetime.date(2019, 3, 19),
-                False), [
+            clp.VersionInfo(clp.VersionNumber(False, 1, 2, 0, "rc2", "12"),
+                            datetime.date(2019, 3, 19), False),
+            [
+                clp.CategoryLog(clp.EntryType.Added, [
+                    clp.EntryLog(
+                        False, "Support for forward slashes \"/\" in net name",
+                        []),
+                ]),
+            ]),
+        clp.VersionLog(
+            clp.VersionInfo(clp.VersionNumber(False, 1, 2, 0, "", "12"),
+                            datetime.date(2019, 3, 19), False),
+            [
+                clp.CategoryLog(clp.EntryType.Changed, [
+                    clp.EntryLog(False, "Use net name in exported file", []),
+                ]),
+            ]),
+        clp.VersionLog(
+            clp.VersionInfo(clp.VersionNumber(
+                False, 1, 2, 0, "1", ""), datetime.date(2019, 3, 19), False), [
                     clp.CategoryLog(clp.EntryType.Added, [
                         clp.EntryLog(
-                            False,
-                            "Support for forward slashes \"/\" in net name"),
+                            False, "Error message window on failed parse", []),
                     ]),
                 ]),
-        clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 1, 2, 0, "", "12"), datetime.date(2019, 3, 19),
-                False), [
-                    clp.CategoryLog(clp.EntryType.Changed, [
-                        clp.EntryLog(False, "Use net name in exported file"),
-                    ]),
-                ]),
-        clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 1, 2, 0, "1", ""), datetime.date(
-                    2019, 3, 19), False), [
-                        clp.CategoryLog(clp.EntryType.Added, [
-                            clp.EntryLog(
-                                False, "Error message window on failed parse"),
-                        ]),
-                    ]),
     ],
 )
 
-
 CHANGELOGA = clp.ChangeLog(
     "AlazarTech Deployment Tools Change Log",
     "This file contains all important changes to the AlazarTech deployment tools",
     [
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(True, 0, 0, 0, "", ""), datetime.date.today(),
-                False), []),
+            clp.VersionInfo(clp.VersionNumber(True, 0, 0, 0, "", ""),
+                            datetime.date.today(), False), []),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 0, 0, 2, "", ""), datetime.date(2019, 1, 25),
-                False),
+            clp.VersionInfo(clp.VersionNumber(False, 0, 0, 2, "", ""),
+                            datetime.date(2019, 1, 25), False),
             [
                 clp.CategoryLog(clp.EntryType.Fixed, [
                     clp.EntryLog(
                         True,
-                        "Make directory copy work even if destination already exists"
-                    ),
+                        "Make directory copy work even if destination already exists",
+                        []),
                 ])
             ]),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 0, 0, 1, "", ""), datetime.date(2019, 1, 23),
-                False), [
+            clp.VersionInfo(clp.VersionNumber(
+                False, 0, 0, 1, "", ""), datetime.date(2019, 1, 23), False), [
                     clp.CategoryLog(clp.EntryType.Added, [
-                        clp.EntryLog(False, "Initial version: deploy.py"),
+                        clp.EntryLog(False, "Initial version: deploy.py", []),
                     ])
                 ]),
     ],
@@ -196,29 +195,26 @@ CHANGELOGB = clp.ChangeLog(
     "This text should get dropped while merging",
     [
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(True, 0, 0, 0, "", ""), datetime.date.today(),
-                False), [
-                    clp.CategoryLog(clp.EntryType.Fixed, [
-                        clp.EntryLog(True, "An entry here"),
-                    ])
-                ]),
+            clp.VersionInfo(clp.VersionNumber(True, 0, 0, 0, "", ""),
+                            datetime.date.today(), False), [
+                                clp.CategoryLog(clp.EntryType.Fixed, [
+                                    clp.EntryLog(True, "An entry here", []),
+                                ])
+                            ]),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 0, 0, 3, "", ""), datetime.date(2019, 1, 26),
-                False), [
-                    clp.CategoryLog(clp.EntryType.Fixed, [
-                        clp.EntryLog(False, "Another here"),
-                    ])
-                ]),
+            clp.VersionInfo(clp.VersionNumber(False, 0, 0, 3, "", ""),
+                            datetime.date(2019, 1, 26), False), [
+                                clp.CategoryLog(clp.EntryType.Fixed, [
+                                    clp.EntryLog(False, "Another here", []),
+                                ])
+                            ]),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 0, 0, 1, "", ""), datetime.date(2019, 1, 22),
-                False), [
-                    clp.CategoryLog(clp.EntryType.Added, [
-                        clp.EntryLog(False, "Third entry"),
-                    ])
-                ]),
+            clp.VersionInfo(clp.VersionNumber(False, 0, 0, 1, "", ""),
+                            datetime.date(2019, 1, 22), False), [
+                                clp.CategoryLog(clp.EntryType.Added, [
+                                    clp.EntryLog(False, "Third entry", []),
+                                ])
+                            ]),
     ],
 )
 
@@ -227,40 +223,36 @@ CHANGELOGMERGED = clp.ChangeLog(
     "This file contains all important changes to the AlazarTech deployment tools",
     [
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(True, 0, 0, 0, "", ""), datetime.date.today(),
-                False), [
-                    clp.CategoryLog(clp.EntryType.Fixed, [
-                        clp.EntryLog(True, "An entry here"),
-                    ])
-                ]),
+            clp.VersionInfo(clp.VersionNumber(True, 0, 0, 0, "", ""),
+                            datetime.date.today(), False), [
+                                clp.CategoryLog(clp.EntryType.Fixed, [
+                                    clp.EntryLog(True, "An entry here", []),
+                                ])
+                            ]),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 0, 0, 3, "", ""), datetime.date(2019, 1, 26),
-                False), [
-                    clp.CategoryLog(clp.EntryType.Fixed, [
-                        clp.EntryLog(False, "Another here"),
-                    ])
-                ]),
+            clp.VersionInfo(clp.VersionNumber(False, 0, 0, 3, "", ""),
+                            datetime.date(2019, 1, 26), False), [
+                                clp.CategoryLog(clp.EntryType.Fixed, [
+                                    clp.EntryLog(False, "Another here", []),
+                                ])
+                            ]),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 0, 0, 2, "", ""), datetime.date(2019, 1, 25),
-                False),
+            clp.VersionInfo(clp.VersionNumber(False, 0, 0, 2, "", ""),
+                            datetime.date(2019, 1, 25), False),
             [
                 clp.CategoryLog(clp.EntryType.Fixed, [
                     clp.EntryLog(
                         True,
-                        "Make directory copy work even if destination already exists"
-                    ),
+                        "Make directory copy work even if destination already exists",
+                        []),
                 ])
             ]),
         clp.VersionLog(
-            clp.VersionInfo(
-                clp.VersionNumber(False, 0, 0, 1, "", ""), datetime.date(2019, 1, 23),
-                False), [
+            clp.VersionInfo(clp.VersionNumber(
+                False, 0, 0, 1, "", ""), datetime.date(2019, 1, 23), False), [
                     clp.CategoryLog(clp.EntryType.Added, [
-                        clp.EntryLog(False, "Initial version: deploy.py"),
-                        clp.EntryLog(False, "Third entry"),
+                        clp.EntryLog(False, "Initial version: deploy.py", []),
+                        clp.EntryLog(False, "Third entry", []),
                     ]),
                 ]),
     ],
@@ -278,12 +270,12 @@ class TestChangeLog(unittest.TestCase):
 
     def test_merge(self):
         self.assertEqual(clp.changelogs_merge([CHANGELOGA]), CHANGELOGA)
-        self.assertEqual(
-            clp.changelogs_merge([CHANGELOGA, CHANGELOGB]), CHANGELOGMERGED)
+        self.assertEqual(clp.changelogs_merge([CHANGELOGA, CHANGELOGB]),
+                         CHANGELOGMERGED)
 
     def test_version(self):
-        self.assertEqual(
-            clp.changelog_version(CHANGELOG), clp.VersionNumber(True, 0, 0, 0, "", ""))
+        self.assertEqual(clp.changelog_version(CHANGELOG),
+                         clp.VersionNumber(True, 0, 0, 0, "", ""))
 
     def test_html(self):
         self.assertEqual(
@@ -298,12 +290,14 @@ class TestChangeLog(unittest.TestCase):
 <h3>Added</h3>
 <ul>
     <li>Initial version: deploy.py</li>
+    <li>Look at this other problem</li>
+    <li>This solves many things. Line break.</li>
 </ul>
 """)
 
     def test_md(self):
         self.assertEqual(
-            clp.changelog_to_md(CHANGELOG,True),
+            clp.changelog_to_md(CHANGELOG, True),
             """# AlazarTech Deployment Tools Change Log
 
 This file contains all important changes to the AlazarTech deployment tools
@@ -318,6 +312,8 @@ This file contains all important changes to the AlazarTech deployment tools
 ## [0.0.1] - 2019-01-23
 ### Added
 - Initial version: deploy.py [#3]
+- Look at this other problem [libats#123]
+- This solves many things. Line break. [libats#123, #34]
 """)
 
     def test_deb(self):
@@ -338,6 +334,8 @@ deptools (0.0.2) UNRELEASED; urgency=medium
 deptools (0.0.1) UNRELEASED; urgency=medium
 
   * Added: Initial version: deploy.py
+  * Added: Look at this other problem
+  * Added: This solves many things. Line break.
 
  -- AlazarTech <support@alazartech.com>  Wed, 23 Jan 2019 12:12:00 -0400
 
@@ -356,16 +354,10 @@ deptools (0.0.1) UNRELEASED; urgency=medium
 * Wed Jan 23 2019 AlazarTech <support@alazartech.com>
 - Version 0.0.1
 - Added: Initial version: deploy.py [#3]
+- Added: Look at this other problem [libats#123]
+- Added: This solves many things. Line break. [libats#123, #34]
 """.format(datetime.date.today().strftime('%a %b %d %Y')))
 
-    def test_public_entry_text(self):
-        self.assertEqual(clp.public_entry_text(
-            '- This is an entry without any ticket refs'),
-                         '- This is an entry without any ticket refs')
-        self.assertEqual(clp.public_entry_text(
-            '- This entry has [#12] multiple [#46] ticket refs'),
-                         '- This entry has multiple ticket refs')
-
 
 if __name__ == "__main__":
     unittest.main()
